@@ -374,7 +374,7 @@ fr_command_arj_finalize (GObject *object)
 GType
 fr_command_arj_get_type ()
 {
-        static guint type = 0;
+        static GType type = 0;
 
         if (! type) {
                 GTypeInfo type_info = {
