@@ -94,8 +94,7 @@ fr_command_cfile_list (FRCommand *comm)
 		fr_process_set_out_line_func (FR_COMMAND (comm)->process, 
 					      list__process_line,
 					      comm);
-		
-		fr_process_clear (comm->process);
+
 		fr_process_begin_command (comm->process, "gzip");
 		fr_process_add_arg (comm->process, "-l");
 		fr_process_add_arg (comm->process, "-q");
@@ -326,7 +325,7 @@ fr_command_cfile_finalize (GObject *object)
 GType
 fr_command_cfile_get_type ()
 {
-        static guint type = 0;
+        static GType type = 0;
 
         if (! type) {
                 GTypeInfo type_info = {
